@@ -22,9 +22,10 @@ define([
     'vp_base/js/com/com_generatorV2',
     'vp_base/data/m_library/pandasLibrary',
     'vp_base/js/com/component/FileNavigation',
-    'vp_base/js/com/component/SuggestInput'
+    'vp_base/js/com/component/SuggestInput',
+    'vp_base/js/com/component/DataSelector'
 ], function(fileHtml, fileCss, com_String, com_util, com_Const, PopupComponent
-            , pdGen, pandasLibrary, FileNavigation, SuggestInput) {
+            , pdGen, pandasLibrary, FileNavigation, SuggestInput, DataSelector) {
 
     /**
      * File
@@ -286,7 +287,14 @@ define([
 
         templateForBody() {
             /** Implement generating template */
-            return fileHtml;
+            let page = $(fileHtml);
+
+            let allocateSelector = new DataSelector({
+                pageThis: this, id: 'vp_sampleReturn', placeholder: 'Variable name'
+            });
+            $(page).find('#vp_sampleReturn').replaceWith(allocateSelector.toTagString());
+
+            return page;
         }
 
         renderPage(pageType) {
